@@ -60,20 +60,23 @@ class Oauth2ClientMiddleware(object):
     CA_CERT_FILE_OPTION = 'ca_cert_file'
     CA_DIR_OPTION = 'ca_dir'
     CLIENT_ID_OPTION = 'client_id'
+    CLIENT_SECRET_OPTION = 'client_secret'
     AUTHORIZATION_ENDPOINT_OPTION = 'authorization_endpoint'
     ACCESS_TOKEN_ENDPOINT_OPTION = 'access_token_endpoint'
     
-    propertyDefaults = {
+    PROPERTY_DEFAULTS = {
         ACCESS_TOKEN_TYPE_OPTION: 'bearer',
         AUTHENTICATION_COMPLETE_OPTION: '',
         AUTHENTICATION_TRIGGER_OPTION: AUTHENTICATION_TRIGGER_ALWAYS,
         AUTHENTICATION_URL_OPTION: 'oauth_authenticate',
         BASE_URL_PATH_OPTION: '',
         CERTIFICATE_REQUEST_PARAMETER_OPTION: 'certificate_request',
-        RENDERER_CLASS_OPTION: 'ndg.oauth.client.lib.render.genshi_renderer.GenshiRenderer',
+        RENDERER_CLASS_OPTION: \
+            'ndg.oauth.client.lib.render.genshi_renderer.GenshiRenderer',
         SCOPE_OPTION: '',
         SESSION_KEY_OPTION: 'beaker.session.oauth2client',
         TOKEN_KEY_OPTION: 'oauth2client.token',
+        CLIENT_SECRET_OPTION: None,
     }
     LAYOUT_PARAMETERS = ['heading',
                          'title',
@@ -88,6 +91,7 @@ class Oauth2ClientMiddleware(object):
                          'footerText',
                          'helpIcon',
                          'client_id',
+                         'client_secret',
                          'client_name',
                          'scope']
 
@@ -185,8 +189,8 @@ class Oauth2ClientMiddleware(object):
         else:
             # Start the OAuth2 transaction to get a token.
             log.debug("Starting OAuth2 protocol")
-            (token, redirect_url) = self._get_token(session,
-                                                    req.application_url)
+            token, redirect_url = self._get_token(session,
+                                                  req.application_url)
             if authenticate_before_delegating and redirect_url:
                 session[self.__class__.SESSION_CALL_CONTEXT_KEY
                                                             ] = original_environ
@@ -223,9 +227,9 @@ class Oauth2ClientMiddleware(object):
                             self._renderingConfiguration.merged_parameters(c))
             
             start_response(self._get_http_status_string(httplib.OK),
-               [('Content-type', 'text/html'),
-                ('Content-length', str(len(response)))
-                ])
+                           [('Content-type', 'text/html'),
+                            ('Content-length', str(len(response)))
+                            ])
             
             return [response]
 
@@ -294,6 +298,8 @@ class Oauth2ClientMiddleware(object):
                                     cls.CERTIFICATE_REQUEST_PARAMETER_OPTION)
         client_id = cls._get_config_option(prefix, local_conf, 
                                            cls.CLIENT_ID_OPTION)
+        client_secret = cls._get_config_option(prefix, local_conf, 
+                                               cls.CLIENT_SECRET_OPTION)
         authorization_endpoint = cls._get_config_option(prefix, local_conf, 
                                             cls.AUTHORIZATION_ENDPOINT_OPTION)
         access_token_endpoint = cls._get_config_option(prefix, local_conf, 
@@ -304,20 +310,24 @@ class Oauth2ClientMiddleware(object):
         redirect_uri = cls.REDIRECT_URI
         
         self.client_config = Oauth2ClientConfig(
-            client_id, authorization_endpoint, access_token_endpoint,
-            base_url_path, redirect_uri,
-            certificate_request_parameter=certificate_request_parameter)
+                    client_id, 
+                    authorization_endpoint, 
+                    access_token_endpoint,
+                    base_url_path, 
+                    redirect_uri,
+                    client_secret=client_secret,
+                    certificate_request_parameter=certificate_request_parameter)
 
     @classmethod
     def _get_config_option(cls, prefix, local_conf, key):
         value = local_conf.get(prefix + key, 
-                               cls.propertyDefaults.get(key, None))
+                               cls.PROPERTY_DEFAULTS.get(key, None))
         log.debug("Oauth2ClientMiddleware configuration %s=%s", key, value)
         return value
 
     @staticmethod
     def _get_http_status_string(status):
-        return ("%d %s" % (status, httplib.responses[status]))
+        return "%d %s" % (status, httplib.responses[status])
 
     @classmethod
     def filter_app_factory(cls, app, app_conf, **local_conf):
@@ -338,12 +348,14 @@ class Oauth2ClientMiddleware(object):
             redirect URI if redirect needed or None
         """
         client = self._oauth_client_class.get_client_instance(session,
-                                                self.client_config, create=True)
+                                                              self.client_config,
+                                                              create=True)
 
         callback = self._token_retriever_class(client)
 
-        (result, redirect_url) = client.call_with_access_token(
-            self.scope, application_url, callback)
+        result, redirect_url = client.call_with_access_token(self.scope, 
+                                                             application_url, 
+                                                             callback)
         session.save()
 
         return (result, redirect_url)
@@ -356,7 +368,8 @@ class Oauth2ClientMiddleware(object):
         @rtype: result type of callback
         @return: result of callback
         """
-        client = self._oauth_client_class.get_client_instance(session,
+        client = self._oauth_client_class.get_client_instance(
+                                                            session,
                                                             self.client_config)
         if client:
             # Return callback result.
@@ -397,6 +410,7 @@ class TokenRetriever(object):
             return None
         return self.client.access_token
 
+
 class MyProxyTokenRetriever(object):
     def __init__(self, client):
         self.client = client
@@ -421,4 +435,4 @@ class MyProxyTokenRetriever(object):
         if error:
             return None
 #            return ("", ("Token not available because of error: %s - %s" % (error, error_description)))
-        return (self.client.private_key, self.client.access_token)
+        return self.client.private_key, self.client.access_token
